import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.4f557c89.js";import{K as c,P as d,L as l}from"./repository.70f10161.js";import{d as f,b as u,ev as b,f as p,u as r}from"./outputWidgets.8e744bdb.js";import{u as g}from"./index.fe22d0e7.js";import{a as y}from"./asyncComputed.317c8625.js";import{a as _}from"./api.057778fa.js";import"./Text.07e986e0.js";import"./Base.bd673c5e.js";import"./index.9fb0ac7b.js";import"./Link.ea06bf6e.js";import"./Paragraph.15ec5eb0.js";import"./Title.d066fbae.js";import"./index.228b2d0d.js";import"./ant-design.296bd3d2.js";import"./index.9183daa3.js";import"./Modal.c54156f6.js";import"./metadata.d51e322e.js";import"./icons.805cd884.js";import"./index.cbd0123e.js";import"./index.e35eed98.js";import"./index.54fb1f83.js";import"./index.78ce1884.js";import"./Card.9b1248c3.js";import"./TabPane.a9cb823a.js";import"./hasIn.23fe66f7.js";import"./CollapsePanel.ca73443a.js";import"./Form.814fe9cf.js";import"./FormItem.22e63e90.js";import"./Timeline.32a5ecc5.js";import"./index.d4a82fb7.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.9cdc57c3.js";import"./index.cf4c23b9.js";import"./scripts.dfa9d19e.js";import"./record.45c6e9c7.js";import"./pubsub.a3628e87.js";import"./ExpandOutlined.34a7339e.js";import"./runnerData.28ea29fd.js";import"./url.9304e931.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="3d6f61ee-2c05-4c98-9ae1-c7ecc270ed75",o._sentryDebugIdIdentifier="sentry-dbid-3d6f61ee-2c05-4c98-9ae1-c7ecc270ed75")}catch{}})();const io=f({__name:"Kanban",setup(o){const t=new d(g),a=new l("kanban"),{result:e}=y(_);return(k,w)=>{var n,i,m;return u(),b("div",null,[p(s,{"brand-name":((n=r(e))==null?void 0:n.brandName)||((i=r(e))==null?void 0:i.name),"logo-url":(m=r(e))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(c,{"kanban-repository":r(t),storage:r(a)},null,8,["kanban-repository","storage"])])}}});export{io as default};
//# sourceMappingURL=Kanban.bc3b34ea.js.map
