import{N as _}from"./NavbarControls.e72c4523.js";import{d as b,eA as f,eB as y,H as g,a as v,b as c,ev as h,f as e,w as s,u as a,e as k,a$ as w,ar as S,c as x,eS as q,v as A}from"./outputWidgets.8e744bdb.js";import{A as B}from"./Text.07e986e0.js";import{T as C,A as o}from"./TabPane.a9cb823a.js";import{c as I}from"./index.228b2d0d.js";import"./asyncComputed.317c8625.js";import"./index.fe22d0e7.js";import"./pubsub.a3628e87.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.bcece02a.js";import"./SaveButton.vue_vue_type_script_setup_true_lang.42eaffa6.js";import"./ant-design.296bd3d2.js";import"./index.9183daa3.js";import"./Modal.c54156f6.js";import"./Base.bd673c5e.js";import"./Link.ea06bf6e.js";import"./index.2b5405cf.js";import"./Paragraph.15ec5eb0.js";import"./workspaces.4aeaa640.js";import"./runnerData.28ea29fd.js";import"./url.9304e931.js";import"./record.45c6e9c7.js";import"./popupNotifcation.c561d2a6.js";import"./CircularLoading.ef3e0493.js";import"./icons.805cd884.js";import"./index.cbd0123e.js";import"./hasIn.23fe66f7.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="64839578-d1a6-4733-9c60-b2a312479e5d",r._sentryDebugIdIdentifier="sentry-dbid-64839578-d1a6-4733-9c60-b2a312479e5d")}catch{}})();const T={class:"content"},D=b({__name:"Settings",setup(r){const t=f(),n=y();function m(){t.push({name:"home"})}const u=g(()=>{switch(n.name){case"settingsStyle":return"style";case"settingsSidebar":return"sidebar";case"settingsRequirements":return"requirements";default:return}});function p(i){switch(i){case"style":t.push({name:"settingsStyle"});break;case"sidebar":t.push({name:"settingsSidebar"});break;case"requirements":t.push({name:"settingsRequirements"});break}}return(i,N)=>{const d=v("router-view");return c(),h(w,null,[e(a(I),{style:{padding:"5px 25px"},onBack:m},{extra:s(()=>[e(_,{"show-v-s-code-button":"","show-save-button":""})]),avatar:s(()=>[e(a(B),null,{default:s(()=>[S("Settings")]),_:1})]),footer:s(()=>[e(a(C),{"active-key":u.value,onChange:p},{default:s(()=>[e(a(o),{key:"style",tab:"Style"}),e(a(o),{key:"sidebar",tab:"Sidebar"}),e(a(o),{key:"requirements",tab:"Requirements"})]),_:1},8,["active-key"])]),_:1}),k("div",T,[e(d,null,{default:s(({Component:l})=>[(c(),x(q(l)))]),_:1})])],64)}}});const oe=A(D,[["__scopeId","data-v-772f4b10"]]);export{oe as default};
//# sourceMappingURL=Settings.42091d88.js.map
