import{d as u,eB as g,H as p,a as b,b as f,c as v,w as r,f as s}from"./outputWidgets.8e744bdb.js";import{B as _}from"./BaseLayout.4ea8fef2.js";import{a as h}from"./asyncComputed.317c8625.js";import"./router.ddb0ef46.js";import"./index.262383aa.js";import{P as z}from"./project.c738ce5c.js";import{O as y}from"./organization.7c8df00d.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.72b9c072.js";import{S as I}from"./Sidebar.6354d94b.js";import{e as w,L as O,M as C,N as B,O as P,P as k,q as L,Q as $,s as M,G as N,H as S,I as x}from"./icons.805cd884.js";import"./FormItem.22e63e90.js";import"./hasIn.23fe66f7.js";import"./index.cf4c23b9.js";import"./record.45c6e9c7.js";import"./pubsub.a3628e87.js";import"./logo.084e5d7c.js";import"./Text.07e986e0.js";import"./Base.bd673c5e.js";import"./index.228b2d0d.js";import"./index.e35eed98.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="d19020dd-1968-4fc9-8725-7bde014c3a2c",o._sentryDebugIdIdentifier="sentry-dbid-d19020dd-1968-4fc9-8725-7bde014c3a2c")}catch{}})();const oa=u({__name:"Project",setup(o){const c=g().params.projectId,{result:a}=h(()=>z.get(c).then(async e=>{const t=await y.get(e.organizationId);return{project:e,organization:t}})),m=p(()=>{var e,t,n,l;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(l=a.value)==null?void 0:l.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),d=p(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Live",path:"live",icon:w},{name:"Builds",path:"builds",icon:O},{name:"Connectors",path:"connectors",icon:C,unavailable:!a.value.organization.featureFlags.CONNECTORS_CONSOLE},{name:"Tables",path:"tables",icon:B},{name:"API Keys",path:"api-keys",icon:P},{name:"Env Vars",path:"env-vars",icon:k},{name:"Files",path:"files",icon:L},{name:"Logs",icon:$,path:"logs"},{name:"Settings",icon:M,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:N,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:S,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:x,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=b("router-view");return f(),v(_,null,{content:r(()=>[s(n)]),navbar:r(()=>[s(j,{class:"nav",breadcrumb:m.value},null,8,["breadcrumb"])]),sidebar:r(()=>[s(I,{class:"sidebar",sections:d.value},null,8,["sections"])]),_:1})}}});export{oa as default};
//# sourceMappingURL=Project.1c00552d.js.map
