import{K as i,E as a,L as s}from"./repository.70f10161.js";import{d as p,b as m,c,u as e}from"./outputWidgets.8e744bdb.js";import{l as d}from"./index.fe22d0e7.js";import"./ant-design.296bd3d2.js";import"./index.9183daa3.js";import"./Modal.c54156f6.js";import"./asyncComputed.317c8625.js";import"./metadata.d51e322e.js";import"./icons.805cd884.js";import"./index.cbd0123e.js";import"./index.e35eed98.js";import"./Paragraph.15ec5eb0.js";import"./Base.bd673c5e.js";import"./index.9fb0ac7b.js";import"./Link.ea06bf6e.js";import"./Text.07e986e0.js";import"./Title.d066fbae.js";import"./index.54fb1f83.js";import"./index.78ce1884.js";import"./Card.9b1248c3.js";import"./TabPane.a9cb823a.js";import"./hasIn.23fe66f7.js";import"./CollapsePanel.ca73443a.js";import"./Form.814fe9cf.js";import"./FormItem.22e63e90.js";import"./Timeline.32a5ecc5.js";import"./index.d4a82fb7.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.9cdc57c3.js";import"./index.cf4c23b9.js";import"./scripts.dfa9d19e.js";import"./record.45c6e9c7.js";import"./pubsub.a3628e87.js";import"./ExpandOutlined.34a7339e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="cfea76e1-9261-4d35-81da-41a076a22825",t._sentryDebugIdIdentifier="sentry-dbid-cfea76e1-9261-4d35-81da-41a076a22825")}catch{}})();class f{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const U=p({__name:"WorkflowKanban",setup(t){const o=new a,r=new f,n=new s("kanban");return(u,y)=>(m(),c(i,{"kanban-repository":e(o),storage:e(n),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{U as default};
//# sourceMappingURL=WorkflowKanban.c77549e4.js.map
