import{a as e,B as f}from"./Base.bd673c5e.js";import{A as a}from"./Link.ea06bf6e.js";import{A as o}from"./Paragraph.15ec5eb0.js";import{A as r}from"./Text.07e986e0.js";import{A as i}from"./Title.d066fbae.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="7330abcd-88ec-4a3d-93fe-03fccf3335fb",n._sentryDebugIdIdentifier="sentry-dbid-7330abcd-88ec-4a3d-93fe-03fccf3335fb")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=a;e.Base=f;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,o),n.component(e.Link.displayName,a),n};
//# sourceMappingURL=index.9fb0ac7b.js.map
