import{S as c}from"./Sidebar.6354d94b.js";import{_ as p}from"./Navbar.vue_vue_type_script_setup_true_lang.72b9c072.js";import{G as d,H as l,I as u}from"./icons.805cd884.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.8e744bdb.js";import{a as w}from"./asyncComputed.317c8625.js";import"./router.ddb0ef46.js";import"./index.262383aa.js";import{O as z}from"./organization.7c8df00d.js";import{B as I}from"./BaseLayout.4ea8fef2.js";import"./index.e35eed98.js";import"./logo.084e5d7c.js";import"./Text.07e986e0.js";import"./Base.bd673c5e.js";import"./index.228b2d0d.js";import"./FormItem.22e63e90.js";import"./hasIn.23fe66f7.js";import"./index.cf4c23b9.js";import"./record.45c6e9c7.js";import"./pubsub.a3628e87.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="c781e5f1-02a5-4cde-9c83-fabb918b64a4",o._sentryDebugIdIdentifier="sentry-dbid-c781e5f1-02a5-4cde-9c83-fabb918b64a4")}catch{}})();const F=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(h,B)=>{const m=_("router-view");return y(),v(I,null,{navbar:t(()=>[r(p,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(c,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{F as default};
//# sourceMappingURL=Organization.2bf4ab24.js.map
