import{r as n,w as r}from"./runnerData.28ea29fd.js";import"./outputWidgets.8e744bdb.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="badfba13-7199-4eaf-9d71-dbab6a370a9c",t._sentryDebugIdIdentifier="sentry-dbid-badfba13-7199-4eaf-9d71-dbab6a370a9c")}catch{}})();async function f(t){const a=await fetch(`/_pages/${t}`);if(a.status==404)return null;if(!a.ok)throw new Error(await a.text());const{form:e}=await a.json();return{form:e&&n(e)}}async function d(){const t=await fetch("/_workspace");if(t.status!=200)return r({});const a=await t.json();return r(a)}export{d as a,f as g};
//# sourceMappingURL=api.057778fa.js.map
