import{_ as f}from"./Navbar.vue_vue_type_script_setup_true_lang.4f557c89.js";import{a as p}from"./api.057778fa.js";import{a as _}from"./asyncComputed.317c8625.js";import{W as y}from"./WidgetsFrame.75d98aa9.js";import{d as g,eB as b,b as n,ev as h,e as a,u as t,c as d,w as v,ex as l,eD as u,v as w}from"./outputWidgets.8e744bdb.js";import"./index.fe22d0e7.js";import"./pubsub.a3628e87.js";import"./Text.07e986e0.js";import"./Base.bd673c5e.js";import"./index.9fb0ac7b.js";import"./Link.ea06bf6e.js";import"./Paragraph.15ec5eb0.js";import"./Title.d066fbae.js";import"./index.228b2d0d.js";import"./runnerData.28ea29fd.js";import"./url.9304e931.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new D().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="92b94de5-e7f7-4232-aa68-ce360e91efb0",o._sentryDebugIdIdentifier="sentry-dbid-92b94de5-e7f7-4232-aa68-ce360e91efb0")}catch{}})();const k={class:"error"},I={class:"inner-content"},x=g({__name:"Error",setup(o){const r=b(),{result:e}=_(p),i=()=>{const{status:s}=r.params;switch(s){case"404":return{status:s,message:"Page not found."};case"403":return{status:s,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(s,B)=>(n(),h("div",null,[a("div",k,[t(e)?(n(),d(y,{key:0,"main-color":t(e).mainColor,theme:t(e).theme,"font-family":t(e).fontFamily,style:{height:"100vh"}},{default:v(()=>{var c,m;return[t(e)?(n(),d(f,{key:0,"brand-name":((c=t(e))==null?void 0:c.brandName)||((m=t(e))==null?void 0:m.name),"logo-url":t(e).logoUrl},null,8,["brand-name","logo-url"])):l("",!0),a("div",I,[a("h1",null,u(i().status),1),a("p",null,u(i().message),1)])]}),_:1},8,["main-color","theme","font-family"])):l("",!0)])]))}});const D=w(x,[["__scopeId","data-v-befb94cf"]]);export{D as default};
//# sourceMappingURL=Error.d6f7a584.js.map
