import{C as r,E as t,K as i,a as b,M as c,c as l,P as y,R as f,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.30ba00f7.js";import"./outputWidgets.8e744bdb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c6a920a5-9b82-45be-b3d2-598d0975013d",e._sentryDebugIdIdentifier="sentry-dbid-c6a920a5-9b82-45be-b3d2-598d0975013d")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,b as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,f as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.5c6e5bf3.js.map
