import{d as b,eB as y,H as g,b as _,c as w,u as h}from"./outputWidgets.8e744bdb.js";import{a as I}from"./asyncComputed.317c8625.js";import{b as k}from"./router.ddb0ef46.js";import"./index.262383aa.js";import{M as n}from"./member.61856cc4.js";import{C as x}from"./CrudView.64d9681d.js";import{F as C}from"./icons.805cd884.js";import{a as M}from"./ant-design.296bd3d2.js";import"./FormItem.22e63e90.js";import"./hasIn.23fe66f7.js";import"./index.cf4c23b9.js";import"./record.45c6e9c7.js";import"./pubsub.a3628e87.js";import"./Paragraph.15ec5eb0.js";import"./Base.bd673c5e.js";import"./Form.814fe9cf.js";import"./Modal.c54156f6.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.bcece02a.js";import"./url.9304e931.js";import"./index.cbd0123e.js";import"./Title.d066fbae.js";import"./Text.07e986e0.js";import"./index.e35eed98.js";import"./index.9183daa3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[i]="20267a0f-5eb3-4979-9da3-b6646db53235",t._sentryDebugIdIdentifier="sentry-dbid-20267a0f-5eb3-4979-9da3-b6646db53235")}catch{}})();const X=b({__name:"Members",setup(t){const a=y().params.organizationId,l=[{key:"email",label:"Email"}],d=async e=>{await n.create(a,e.email),m()};async function c(e){await M("Are you sure you want to remove this member's access?")&&(await n.delete(a,e.authorId),m())}const{loading:p,result:u,refetch:m}=I(()=>n.list(a)),f=g(()=>{var e,r;return{columns:[{name:"Email",align:"left"},{name:"Role"},{name:"",align:"right"}],rows:(r=(e=u.value)==null?void 0:e.map(o=>{var s;return{key:o.email,cells:[{type:"text",text:o.email},{type:"text",text:o.role},{type:"actions",actions:((s=k.getAuthor())==null?void 0:s.claims.email)===o.email?[]:[{icon:C,label:"Remove access",onClick:()=>c(o),dangerous:!0}]}]}}))!=null?r:[]}});return(e,r)=>(_(),w(x,{"entity-name":"members",loading:h(p),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:f.value,"create-button-text":"Add members",fields:l,onCreate:d},null,8,["loading","table"]))}});export{X as default};
//# sourceMappingURL=Members.5cc79250.js.map
