import{a as c}from"./api.057778fa.js";import{P as m}from"./Passwordless.be99935f.js";import{a as f}from"./asyncComputed.317c8625.js";import{W as p}from"./WidgetsFrame.75d98aa9.js";import{d as u,eA as l,eB as _,b as d,ev as y,e as g,u as s,c as h,w,ex as b,f as v,v as k}from"./outputWidgets.8e744bdb.js";import"./runnerData.28ea29fd.js";import"./url.9304e931.js";import"./index.fe22d0e7.js";import"./pubsub.a3628e87.js";import"./icons.805cd884.js";import"./CircularLoading.ef3e0493.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="59324927-56c5-47f9-9ecd-f582062d1f6a",e._sentryDebugIdIdentifier="sentry-dbid-59324927-56c5-47f9-9ecd-f582062d1f6a")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),r=_(),{result:o}=f(c),i=()=>{const{redirect:a,...n}=r.query;if(a){t.push({path:a,query:n,params:r.params});return}t.push({name:"playerKanban",query:n})};return(a,n)=>(d(),y("div",null,[g("div",x,[s(o)?(d(),h(p,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:w(()=>[v(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):b("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.7e1a091b.js.map
