import{V as s,f as p,Q as d}from"./outputWidgets.8e744bdb.js";import{B as f,b as i}from"./Base.bd673c5e.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="706bc3aa-7725-42f3-935e-b5673074992c",a._sentryDebugIdIdentifier="sentry-dbid-706bc3aa-7725-42f3-935e-b5673074992c")}catch{}})();const c=()=>d(i(),["component"]),r=(a,e)=>{let{slots:t,attrs:o}=e;const n=s(s(s({},a),{component:"div"}),o);return p(f,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=c();const g=r;export{g as A};
//# sourceMappingURL=Paragraph.15ec5eb0.js.map
