import"./outputWidgets.8e744bdb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9caa2136-61f8-4645-973c-ae55b5302c79",e._sentryDebugIdIdentifier="sentry-dbid-9caa2136-61f8-4645-973c-ae55b5302c79")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.9304e931.js.map
