import{V as s}from"./outputWidgets.8e744bdb.js";import{c as i,d}from"./index.5da223b2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4cd644cc-451e-4910-8015-6e2cf4a3fc41",e._sentryDebugIdIdentifier="sentry-dbid-4cd644cc-451e-4910-8015-6e2cf4a3fc41")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:f,TimePicker:m,QuarterPicker:c,RangePicker:o}=i(d),g=s(n,{WeekPicker:r,MonthPicker:t,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:c,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(c.name,c),e)});export{g as D,t as M,c as Q,o as R,r as W};
//# sourceMappingURL=dayjs.2b3c7618.js.map
