import{v as t,b as a,ev as s}from"./outputWidgets.8e744bdb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="42a64b3b-a501-4352-aba6-7dd13a593c62",e._sentryDebugIdIdentifier="sentry-dbid-42a64b3b-a501-4352-aba6-7dd13a593c62")}catch{}})();const o={},r={class:"organization-settings"};function d(e,n){return a(),s("div",r,"Organization settings")}const f=t(o,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.b44a178f.js.map
