import{d as f,eB as m,u as e,b as d,c as u,ev as y,f as a,w as o,bv as _,ar as p,ex as b,e as g,eD as x}from"./outputWidgets.8e744bdb.js";import"./router.ddb0ef46.js";import"./index.262383aa.js";import{O as w}from"./organization.7c8df00d.js";import{a as k}from"./asyncComputed.317c8625.js";import{A}from"./Title.d066fbae.js";import{A as B}from"./index.cbd0123e.js";import{A as h}from"./index.9c1b7d5c.js";import{A as C}from"./Text.07e986e0.js";import{C as v}from"./Card.9b1248c3.js";import"./FormItem.22e63e90.js";import"./hasIn.23fe66f7.js";import"./index.cf4c23b9.js";import"./record.45c6e9c7.js";import"./pubsub.a3628e87.js";import"./Base.bd673c5e.js";import"./TabPane.a9cb823a.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="70a9c315-91aa-472e-8b68-b92e95abb548",t._sentryDebugIdIdentifier="sentry-dbid-70a9c315-91aa-472e-8b68-b92e95abb548")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},Q=f({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:l,result:c}=k(()=>w.get(n));return(z,N)=>e(l)?(d(),u(e(_),{key:0})):(d(),y("div",D,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[p("Current plan")]),_:1}),b("",!0)]),_:1}),a(e(h),{style:{"margin-top":"0"}}),a(e(v),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),g("div",I,x((s=(i=e(c))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{Q as default};
//# sourceMappingURL=Billing.8963b814.js.map
